// Copyright (c) FIRST and other WPILib contributors.
// Open Source Software; you can modify and/or share it under the terms of
// the WPILib BSD license file in the root directory of this project.

package frc.robot;

import edu.wpi.first.wpilibj.shuffleboard.BuiltInWidgets;
import edu.wpi.first.wpilibj.shuffleboard.Shuffleboard;
import edu.wpi.first.wpilibj.shuffleboard.ShuffleboardTab;
import edu.wpi.first.wpilibj2.command.Command;
import edu.wpi.first.wpilibj2.command.Commands;
import edu.wpi.first.wpilibj2.command.button.CommandXboxController;
import frc.robot.subsystems.ClosedLoopTest;

import static frc.robot.constants.OIConstants.*;

public class RobotContainer {
    private CommandXboxController driver;

    private ClosedLoopTest closedLoopTest;

    public RobotContainer() {
        driver = new CommandXboxController(kDriverUSB);

        closedLoopTest = new ClosedLoopTest();

        configureBindings();

        configureShuffleboard();
    }

    private void configureBindings() {
        driver.x().onTrue(
            closedLoopTest.setPosition(360)
        );

        driver.b().onTrue(
            closedLoopTest.setPosition(0)
        );

        driver.y().onTrue(
            closedLoopTest.setVelocity(360)
        );

        driver.a().onTrue(
            closedLoopTest.setVelocity(0)
        );
    }

    public Command getAutonomousCommand() {
        return Commands.print("No autonomous command configured");
    }

    public void configureShuffleboard() {
    	ShuffleboardTab sensorTab = Shuffleboard.getTab(kSensorsTab);

		Shuffleboard.selectTab(kSensorsTab);

        sensorTab.addDouble("Position", closedLoopTest::getEncoderPosition)
			.withSize(0, 0)
			.withPosition(0, 0)
			.withWidget(BuiltInWidgets.kTextView);
    }
}
